import { RequestState, FieldConfiguration, FacetConfiguration } from '@elastic/search-ui';

declare function adaptRequest(requestState: RequestState, queryConfig: SiteSearchQueryConfig, documentType: string): {
    q: string;
    search_fields: {
        [x: string]: string[];
    };
    highlight_fields: {
        [x: string]: Record<string, {
            size?: number;
            fallback?: boolean;
        }>;
    };
    fetch_fields: {
        [x: string]: string[];
    };
    facets: {
        [x: string]: string[];
    };
    filters: {
        [x: string]: {};
    };
    sort_list: {
        [x: string]: any;
    };
    sort_field: {
        [x: string]: string | Record<string, string>;
    };
    sort_direction: {
        [x: string]: "asc" | "desc" | Record<string, "asc" | "desc">;
    };
    page: number;
    per_page: number;
};

type Boost = "logarithmic" | "linear" | "exponential";
type SiteSearchQueryConfig = {
    resultsPerPage?: number;
    current?: number;
    sortDirection?: Record<string, "asc" | "desc">;
    sortField?: Record<string, string>;
    sortList?: any;
    result_fields?: Record<string, FieldConfiguration>;
    search_fields?: Record<string, string[]>;
    facets?: Record<string, FacetConfiguration>;
    spelling?: "strict" | "always" | "retry";
    functional_boosts?: Record<string, Record<string, Boost>>;
    document_types?: string[];
    [key: string]: any;
};
type SearchQueryHook = (queryOptions: ReturnType<typeof adaptRequest>, next: (newQueryOptions: ReturnType<typeof adaptRequest>) => any) => any;
type SiteSearchAPIConnectorParams = {
    documentType: string;
    engineKey: string;
    beforeSearchCall?: SearchQueryHook;
    beforeAutocompleteResultsCall?: SearchQueryHook;
};

declare class SiteSearchAPIConnector {
    /**
     * @callback next
     * @param {Object} updatedQueryOptions The options to send to the API
     */
    /**
     * @callback hook
     * @param {Object} queryOptions The options that are about to be sent to the API
     * @param {next} next The options that are about to be sent to the API
     */
    /**
     * @typedef Options
     * @param  {string} documentType Document Type found in your Site Search Dashboard
     * @param  {string} engineKey Credential found in your Site Search Dashboard
     * @param  {hook} beforeSearchCall=(queryOptions,next)=>next(queryOptions) A hook to amend query options before the request is sent to the
     *   API in a query on an "onSearch" event.
     * @param  {hook} beforeAutocompleteResultsCall=(queryOptions,next)=>next(queryOptions) A hook to amend query options before the request is sent to the
     *   API in a "results" query on an "onAutocomplete" event.
     */
    /**
     * @param {Options} options
     */
    _get: (path: string, params: Record<string, any>) => Promise<Response>;
    request: (method: string, path: string, params: Record<string, any>) => Promise<any>;
    beforeAutocompleteResultsCall: SearchQueryHook;
    documentType: string;
    engineKey: string;
    beforeSearchCall: SearchQueryHook;
    constructor({ documentType, engineKey, beforeSearchCall, beforeAutocompleteResultsCall }: SiteSearchAPIConnectorParams);
    onResultClick({ query, documentId, tags }: {
        query: string;
        documentId: string;
        tags: string[];
    }): void;
    onAutocompleteResultClick({ query, documentId, tags }: {
        query: string;
        documentId: string;
        tags: string[];
    }): void;
    onSearch(requestState: RequestState, queryConfig: SiteSearchQueryConfig): any;
    onAutocomplete({ searchTerm }: {
        searchTerm: string;
    }, queryConfig: {
        results?: SiteSearchQueryConfig;
        [key: string]: any;
    }): Promise<any>;
}

export { SiteSearchAPIConnector as default };
