var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/requestAdapters.ts
import { helpers } from "@elastic/search-ui";
function adaptFilterType(type) {
  if (type === "any") return {};
  if (type === "all") return { type: "and" };
  return { type: "and" };
}
function adaptFacetConfig(facets) {
  if (!facets) return;
  const convertInvalidFacetsToUndefined = ([fieldName, config2]) => {
    if (config2.type != "value") {
      console.warn(
        `search-ui-site-search-connector: Dropping ${fieldName} facet, only value facets are supported in Site Search`
      );
      return void 0;
    }
    if (config2.sort) {
      console.warn(
        "search-ui-site-search-connector: Site Search does not support 'sort' on facets"
      );
    }
    if (config2.size) {
      console.warn(
        "search-ui-site-search-connector: Site Search does not support 'size' on facets"
      );
    }
    return [fieldName, config2];
  };
  const config = Object.entries(facets).map(convertInvalidFacetsToUndefined).filter((v) => v).map(([key]) => key);
  if (!config.length) return;
  return config;
}
function adaptFilterConfig(filters) {
  if (!filters || Object.keys(filters).length === 0) return;
  return filters.reduce((acc, filter) => {
    const fieldName = filter.field;
    const fieldValue = filter.values;
    if (acc[fieldName]) {
      console.warn(
        "search-ui-site-search-connector: More than one filter found for a single field"
      );
      return acc;
    }
    if (filter.type && filter.type !== "all" && filter.type !== "any") {
      console.warn(
        `search-ui-site-search-connector: Unsupported filter type "${filter.type}" found, only "all" and "any" are currently supported`
      );
      return acc;
    }
    if (fieldValue.find((v) => typeof v === "object") !== void 0) {
      if (fieldValue.length > 1) {
        console.warn(
          "search-ui-site-search-connector: Cannot apply more than 1 none-value filters to a single field"
        );
        return acc;
      }
      const firstValue = fieldValue[0];
      if (helpers.isFilterValueRange(firstValue)) {
        const _a = firstValue, { name } = _a, rest = __objRest(_a, ["name"]);
        acc[fieldName] = __spreadValues({
          type: "range"
        }, rest);
        return acc;
      } else {
        return acc;
      }
    }
    acc[fieldName] = __spreadProps(__spreadValues({}, adaptFilterType(filter.type)), {
      values: fieldValue
    });
    return acc;
  }, {});
}
function adaptResultFieldsConfig(resultFieldsConfig) {
  if (!resultFieldsConfig) return [];
  const fetchFields = Object.keys(resultFieldsConfig);
  const highlightFields = Object.entries(resultFieldsConfig).reduce(
    (acc, [fieldName, fieldConfig]) => {
      if (!fieldConfig.snippet) return acc;
      return __spreadProps(__spreadValues({}, acc), {
        [fieldName]: fieldConfig.snippet
      });
    },
    {}
  );
  return [fetchFields, highlightFields];
}
function adaptSearchFieldsConfig(searchFieldsConfig) {
  if (!searchFieldsConfig) return [];
  return Object.keys(searchFieldsConfig);
}

// src/requestAdapter.ts
function adaptRequest(requestState, queryConfig, documentType) {
  const { disjunctiveFacets, disjunctiveFacetsAnalyticsTags } = queryConfig;
  if (disjunctiveFacets) {
    console.warn(
      "search-ui-site-search-connector: disjunctiveFacets is not supported by Site Search"
    );
  }
  if (disjunctiveFacetsAnalyticsTags) {
    console.warn(
      "search-ui-site-search-connector: disjunctiveFacetsAnalyticsTags is not supported by Site Search"
    );
  }
  const updatedFacets = adaptFacetConfig(queryConfig.facets);
  const updatedFilters = adaptFilterConfig(
    queryConfig.filters !== void 0 ? queryConfig.filters : requestState.filters
  );
  const page = queryConfig.current !== void 0 ? queryConfig.current : requestState.current;
  const per_page = queryConfig.resultsPerPage !== void 0 ? queryConfig.resultsPerPage : requestState.resultsPerPage;
  const sortDirection = queryConfig.sortDirection !== void 0 ? queryConfig.sortDirection : requestState.sortDirection;
  const sortField = queryConfig.sortField !== void 0 ? queryConfig.sortField : requestState.sortField;
  const sortList = queryConfig.sortList !== void 0 ? queryConfig.sortList : requestState.sortList;
  const [fetchFields, highlightFields] = adaptResultFieldsConfig(
    queryConfig.result_fields
  );
  const updatedSearchFields = adaptSearchFieldsConfig(
    queryConfig.search_fields
  );
  const searchTerm = requestState.searchTerm;
  return __spreadProps(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues({}, per_page && { per_page }), page && { page }), sortDirection && {
    sort_direction: {
      [documentType]: sortDirection
    }
  }), sortField && {
    sort_field: {
      [documentType]: sortField
    }
  }), sortList && {
    sort_list: {
      [documentType]: sortList
    }
  }), updatedFilters && {
    filters: {
      [documentType]: updatedFilters
    }
  }), updatedFacets && {
    facets: {
      [documentType]: updatedFacets
    }
  }), fetchFields && {
    fetch_fields: {
      [documentType]: fetchFields
    }
  }), highlightFields && {
    highlight_fields: {
      [documentType]: highlightFields
    }
  }), updatedSearchFields && !!updatedSearchFields.length && {
    search_fields: {
      [documentType]: updatedSearchFields
    }
  }), {
    q: searchTerm
  });
}

// src/responseAdapters.ts
var addEachKeyValueToObject = (acc, [key, value]) => __spreadProps(__spreadValues({}, acc), {
  [key]: value
});
function getFacets(docInfo) {
  if (!docInfo.facets) return {};
  return Object.entries(docInfo.facets).map(([facetName, facetValue]) => {
    return [
      facetName,
      [
        {
          field: facetName,
          data: Object.entries(facetValue).map(([value, count]) => ({
            value,
            count
          })),
          // Site Search does not support any other type of facet
          type: "value"
        }
      ]
    ];
  }).reduce(addEachKeyValueToObject, {});
}
function getResults(records, documentType) {
  const isMetaField = (key) => key.startsWith("_");
  const toObjectWithRaw = (value) => ({ raw: value });
  return records[documentType].map((record) => {
    const _a = record, { highlight, sort } = _a, rest = __objRest(_a, ["highlight", "sort"]);
    const result = Object.entries(rest).filter(([fieldName]) => !isMetaField(fieldName)).map(([fieldName, fieldValue]) => [
      fieldName,
      toObjectWithRaw(fieldValue)
    ]).reduce(addEachKeyValueToObject, {});
    Object.entries(highlight).forEach(([key, value]) => {
      result[key].snippet = value;
    });
    return result;
  });
}

// src/responseAdapter.ts
function adaptResponse(response, documentType) {
  const results = getResults(response.records, documentType);
  const totalPages = response.info[documentType].num_pages;
  const totalResults = response.info[documentType].total_result_count;
  const requestId = "";
  const facets = getFacets(response.info[documentType]);
  return __spreadValues({
    rawResponse: response,
    results,
    totalPages,
    totalResults,
    requestId
  }, Object.keys(facets).length > 0 && { facets });
}

// src/request.ts
function request(engineKey, method, path, params) {
  return __async(this, null, function* () {
    const headers = new Headers({
      "Content-Type": "application/json"
    });
    const response = yield fetch(
      `https://search-api.swiftype.com/api/v1/public/${path}`,
      {
        method,
        headers,
        body: JSON.stringify(__spreadValues({
          engine_key: engineKey
        }, params)),
        credentials: "include"
      }
    );
    let json;
    try {
      json = yield response.json();
    } catch (error) {
    }
    if (response.status >= 200 && response.status < 300) {
      return json;
    } else {
      const message = json && json.errors && Object.entries(json.errors).length > 0 ? JSON.stringify(json.errors) : response.status;
      throw new Error(`${message}`);
    }
  });
}

// src/SiteSearchAPIConnector.ts
function _get(engineKey, path, params) {
  const query = Object.entries(__spreadValues({ engine_key: engineKey }, params)).map(([paramName, paramValue]) => {
    return `${paramName}=${encodeURIComponent(paramValue)}`;
  }).join("&");
  return fetch(
    `https://search-api.swiftype.com/api/v1/public/${path}?${query}`,
    {
      method: "GET",
      credentials: "include"
    }
  );
}
var SiteSearchAPIConnector = class {
  constructor({
    documentType,
    engineKey,
    beforeSearchCall = (queryOptions, next) => next(queryOptions),
    beforeAutocompleteResultsCall = (queryOptions, next) => next(queryOptions)
  }) {
    this.documentType = documentType;
    this.engineKey = engineKey;
    this.beforeSearchCall = beforeSearchCall;
    this.beforeAutocompleteResultsCall = beforeAutocompleteResultsCall;
    this.request = request.bind(this, engineKey);
    this._get = _get.bind(this, engineKey);
  }
  onResultClick({
    query,
    documentId,
    tags
  }) {
    if (tags && tags.length > 0) {
      console.warn(
        "search-ui-site-search-connector: Site Search does not support tags on click"
      );
    }
    this._get("analytics/pc", {
      t: (/* @__PURE__ */ new Date()).getTime(),
      q: query,
      doc_id: documentId
    });
  }
  onAutocompleteResultClick({
    query,
    documentId,
    tags
  }) {
    if (tags) {
      console.warn(
        "search-ui-site-search-connector: Site Search does not support tags on autocompleteClick"
      );
    }
    this._get("analytics/pas", {
      t: (/* @__PURE__ */ new Date()).getTime(),
      q: query,
      doc_id: documentId
    });
  }
  onSearch(requestState, queryConfig) {
    const options = adaptRequest(requestState, queryConfig, this.documentType);
    return this.beforeSearchCall(
      options,
      (newOptions) => this.request("POST", "engines/search.json", newOptions).then(
        (json) => adaptResponse(json, this.documentType)
      )
    );
  }
  onAutocomplete(_0, _1) {
    return __async(this, arguments, function* ({ searchTerm }, queryConfig) {
      if (queryConfig.results) {
        const options = adaptRequest(
          { searchTerm },
          queryConfig.results,
          this.documentType
        );
        return this.beforeAutocompleteResultsCall(
          options,
          (newOptions) => this.request("POST", "engines/suggest.json", newOptions).then(
            (json) => ({
              autocompletedResults: adaptResponse(json, this.documentType).results
            })
          )
        );
      }
      if (queryConfig.suggestions) {
        console.warn(
          "search-ui-site-search-connector: Site Search does support query suggestions on autocomplete"
        );
      }
    });
  }
};
var SiteSearchAPIConnector_default = SiteSearchAPIConnector;
export {
  SiteSearchAPIConnector_default as default
};
//# sourceMappingURL=index.mjs.map